@@ -36,11 +36,14 @@ Please use the standard Base64 encoding scheme (with the "=" padding). For the e
         :param LivenessType: Liveness detection type. Valid values: LIP/ACTION/SILENT.
 LIP: numeric mode; ACTION: motion mode; SILENT: silent mode. You need to select a mode to input.
         :type LivenessType: str
-        :param ValidateData: Input parameter for the numeric mode: numeric verification code (1234). An API needs to be called first to get a numeric verification code;
-Input parameter for the motion mode: motion order (2,1 or 1,2). An API needs to be called first to get the motion order;
-Input parameter for silent mode: empty.
+        :param ValidateData: Lip mode: set this parameter to a custom 4-digit verification code.
+Action mode: set this parameter to a custom action sequence (e.g., `2,1` or `1,2`).
+Silent mode: do not pass in this parameter.
         :type ValidateData: str
-        :param Optional: This parameter does not need to be passed in for this API.
+        :param Optional: Optional configuration (a JSON string)
+{
+"BestFrameNum": 2  // Return multiple best screenshots. Value range: 2−10
+}
         :type Optional: str
         """
         self.ImageBase64 = None
